Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(42)

Unified Diff: milo/common/gitiles/gitiles.go

Issue 2981753002: Gitiles: commit's author and committer are the same structures. (Closed)
Patch Set: review + bug Created 3 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: milo/common/gitiles/gitiles.go
diff --git a/milo/common/gitiles/gitiles.go b/milo/common/gitiles/gitiles.go
index 7fd41c69761e173d4dc0ea42af53cfbb3ec4e47e..4579a97f828960cfd661b43317876617398a1f54 100644
--- a/milo/common/gitiles/gitiles.go
+++ b/milo/common/gitiles/gitiles.go
@@ -35,15 +35,8 @@ type Repo struct {
Branch string
}
-// Author is the author returned from a gitiles log request.
-type Author struct {
- Name string `json:"name"`
- Email string `json:"email"`
- Time string `json:"time"`
-}
-
-// Committer is the committer information returned from a gitiles log request.
-type Committer struct {
+// User is the author or the committer returned from a gitiles log request.
+type User struct {
Name string `json:"name"`
Email string `json:"email"`
Time string `json:"time"`
@@ -51,12 +44,12 @@ type Committer struct {
// Log is the Log information of a commit returned from a gitiles log request.
type Log struct {
- Commit string `json:"commit"`
- Tree string `json:"tree"`
- Parents []string `json:"parents"`
- Author Author `json:"author"`
- Committer Committer `json:"committer"`
- Message string `json:"message"`
+ Commit string `json:"commit"`
+ Tree string `json:"tree"`
+ Parents []string `json:"parents"`
+ Author User `json:"author"`
+ Committer User `json:"committer"`
+ Message string `json:"message"`
}
// Commit is the JSON response from querying gitiles for a log request.
« no previous file with comments | « no previous file | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698